@@ -6,18 +6,18 @@ import hashlib
 import json
 import logging
 import os
+import pathlib
 import re
+import shutil
+import tempfile
+import zipfile
 from collections import OrderedDict, defaultdict
 from dataclasses import dataclass
 from itertools import groupby
 from pathlib import Path
-from typing import Any, Dict, List, NamedTuple, Union
+from typing import Any, Dict, Generator, List, NamedTuple, Union, Tuple
 from zipfile import BadZipFile
 
-from openpyxl import load_workbook
-from openpyxl.worksheet.cell_range import MultiCellRange
-from openpyxl.worksheet.worksheet import Worksheet
-
 from engine.config import Config
 from engine.domain.datamap import DatamapFile, DatamapLine, DatamapLineValueType
 from engine.domain.template import TemplateCell
@@ -29,8 +29,12 @@ from engine.exceptions import (
     MissingLineError,
     MissingSheetFieldError,
     NoApplicableSheetsInTemplateFiles,
+    NestedZipError,
 )
 from engine.utils import ECHO_FUNC_GREEN, ECHO_FUNC_YELLOW
+from openpyxl import load_workbook
+from openpyxl.worksheet.cell_range import MultiCellRange
+from openpyxl.worksheet.worksheet import Worksheet
 
 FILE_DATA = Dict[str, Union[str, Dict[str, Dict[str, str]]]]
 DAT_DATA = Dict[str, FILE_DATA]
@@ -502,3 +506,29 @@ def template_reader(template_file) -> Dict[str, Dict[str, Dict[Any, Any]]]:
     shell_dict = {f_path.name: inner_dict}
     logger.info(f"Compiled data from {f_path.name}")
     return shell_dict
+
+
+def extract_zip_file_to_tmpdir(
+    zfile,
+) -> Tuple[str, List[pathlib.Path]]:
+    """
+    Extracts files inside zfile to a temporary dirctory, and yields
+    a generator of the files as Path objects.
+    """
+    output = []
+    tmp_dir = tempfile.mkdtemp()
+    with zipfile.ZipFile(zfile, "r") as zf:
+        zf.extractall(tmp_dir)
+        target_files = [
+            x for x in os.listdir(tmp_dir) if re.match(r"(^.+\.xlsx|^.+\.xlsm)", x)
+        ]
+        if target_files:
+            for p in os.listdir(tmp_dir):
+                out = pathlib.Path(tmp_dir) / p
+                if out.suffix in [".xlsx", ".xlsm"]:
+                    output.append(pathlib.Path(tmp_dir) / p)
+            return tmp_dir, output
+        else:
+            raise NestedZipError(
+                f"{zfile} contains nested directories and files. Must be flat containing only target files. For UNIX systems, use -j flag with zip."
+            )
