@@ -109,6 +109,18 @@ def datamapline_list_objects() -> List[DatamapLine]:
     return [dml1, dml2, dml3, dml4]
 
 
+@pytest.fixture
+def templates_zipped() -> Path:
+    here = os.path.abspath(os.curdir)
+    yield Path(os.path.join(here, "tests/resources/templates.zip"))
+
+
+@pytest.fixture
+def templates_zipped_deep_structure() -> Path:
+    here = os.path.abspath(os.curdir)
+    return Path(os.path.join(here, "tests/resources/templates_deep_structure.zip"))
+
+
 @pytest.fixture
 def dat_file() -> Path:
     """A data file containing data from a single spreadsheet.
